move_vertex_to_average_3d

Function move_vertex_to_average_3d 

pub fn move_vertex_to_average_3d<T: CoordsFloat>(
    t: &mut Transaction,
    map: &CMap3<T>,
    vid: VertexIdType,
    others: &[VertexIdType],
) -> StmClosureResult<()>
Move a 3-map vertex to the average of the supplied neighboring vertices.

Errors

This function will abort and raise an error if the transaction cannot be completed.

Panics

This function may panic if one of the vertices has no associated coordinates.