neighbor_based_smooth_3d

Function neighbor_based_smooth_3d 

pub fn neighbor_based_smooth_3d<T: CoordsFloat>(
    t: &mut Transaction,
    map: &CMap3<T>,
    vid: VertexIdType,
    neighbors_id: &[VertexIdType],
    lambda: T,
) -> StmClosureResult<()>
Smooth a 3-map vertex toward the average of the supplied neighboring vertices.

Errors

This function will abort and raise an error if the transaction cannot be completed.

Panics

This function may panic if one of the vertices has no associated coordinates.